==> larus_board-0.8.36.tbz: larus_board-0.8.36/lb_private/lang/en/topic.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'deny_by_topic_acl'=>'You are not allowed to read this topic as you were rejected by its access control list',
'topic_view'=>'Topic View',
'post_new_reply'=>'Post new reply',
'posting_edited_by'=>'Edited by',
'posting_edited_reason'=>'Reason',
'posting_has_been_ignored'=>'The author of this posting is located on your blacklist
and therefore you cannot see his message.',
'posting_see_ignored_either'=>'Show the message anyway',
'posting_invisible'=>'Note: This posting is unapproved and invisible to common users.',
'add_to_blacklist'=>'Add author to blacklist',
'remove_from_blacklist'=>'Remove author from blacklist',
'delete_report_posting_request'=>'I checked this posting and remove the "Posting Report Request"...',
'edit_profile'=>'Edit user account',
'moderation'=>'Moderation',
'set_post_visible'=>'Set visible',
'set_post_hidden'=>'Set hidden',
'open_topic'=>'Open topic',
'close_topic'=>'Close topic',
'edit_post'=>'Edit',
'delete_post'=>'Delete',
'link_to_this_posting'=>'Permanent-Link',
'report_posting'=>'Report Posting',
'add_bookmark'=>'Add a bookmark',
'remove_bookmark'=>'Remove this bookmark',
'back_to_search_results'=>'Back to search results'
);
?>

==> larus_board-0.9.0.tbz: larus_board-0.9.0/lb_private/lang/en/topic.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'deny_by_topic_acl'=>'You are not allowed to read this topic as you were rejected by its access control list',
'topic_view'=>'Topic View',
'post_new_reply'=>'Post new reply',
'post_quoted_reply'=>'Quote',
'posting_edited_by'=>'Edited by',
'posting_edited_reason'=>'Reason',
'posting_has_been_ignored'=>'The author of this posting is located on your blacklist
and therefore you cannot see his message.',
'posting_see_ignored_either'=>'Show the message anyway',
'posting_invisible'=>'Note: This posting is unapproved and invisible to common users.',
'purge_post_cache'=>'Purge Posting Cache',
'purge_topic_cache'=>'Purge Topic Cache',
'add_to_blacklist'=>'Add author to blacklist',
'remove_from_blacklist'=>'Remove author from blacklist',
'delete_report_posting_request'=>'I checked this posting and remove the "Posting Report Request"...',
'edit_profile'=>'Edit user account',
'moderation'=>'Moderation',
'set_post_visible'=>'Set visible',
'set_post_hidden'=>'Set hidden',
'open_topic'=>'Open topic',
'close_topic'=>'Close topic',
'edit_post'=>'Edit',
'delete_post'=>'Delete',
'link_to_this_posting'=>'Permanent-Link',
'report_posting'=>'Report Posting',
'add_bookmark'=>'Add a bookmark',
'remove_bookmark'=>'Remove this bookmark',
'back_to_search_results'=>'Back to search results',
'other_topics_related_to_owner'=>'The topic starter also wrote',
'other_topics_related_to_subject'=>'These topics are related'
);
?>
